import { createApi, fetchBaseQuery } from '@reduxjs/toolkit/query/react';
import {getConfigValue} from "@brojs/cli";

const LOCAL = "http://localhost:8099";
const DEV = "https://dev.bro-js.ru";

export const BASE_API_URL = LOCAL + getConfigValue("enterfront.api");

const baseQuery = fetchBaseQuery({
    baseUrl: BASE_API_URL,
    prepareHeaders: (headers) => {
        const token = localStorage.getItem('token');
        if (token) {
            headers.set('Authorization', `Bearer ${token}`);
        }
        return headers;
    },
});

export const apiSlice = createApi({
    reducerPath: 'api',
    baseQuery,
    endpoints: (builder) => ({
        getChats: builder.query({
            query: (username) => `/chat/list/${username}`,
        }),
        postChat: builder.mutation({
            query: (body) => ({
                url: '/chat/post',
                method: 'POST',
                body,
            }),
        }),
        // Add more endpoints as needed
    }),
});

// Export hooks for usage in functional components
export const { useGetChatsQuery, usePostChatMutation } = apiSlice;